/*******************************************************************************
 * Copyright (c) 2004, 2005 IBM Corporation.
 * All rights reserved. 
 *******************************************************************************/
package com.ibm.samplesgallery.servlets;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.ibm.samplegallery.internal.GalleryConstants;
import com.ibm.samplegallery.internal.GalleryMenuViewer;
import com.ibm.samplegallery.internal.GalleryTreeNode;
import com.ibm.samplegallery.SampleGalleryAction;

/**
 * Process request for displaying the tree view. Also handles initial selection of samples.
 */
public class GalleryNavigatorContainer extends HttpServlet implements GalleryConstants {
	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		processRequest(req, res);
	}
	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		processRequest(req, res);
	}
	public void processRequest(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		GalleryMenuViewer menuViewer = null;
		HttpSession httpSession = req.getSession(false);
		String localeName = req.getHeader("ACCEPT-LANGUAGE"); //$NON-NLS-1$
		// if there is not an HttpSession, then create one
		if (httpSession == null) {
			// create an http Session
			httpSession = req.getSession();
			menuViewer = new GalleryMenuViewer();
			httpSession.setAttribute(SessionAttributes.MENU_VIEWER, menuViewer);
		} else {
			menuViewer = (GalleryMenuViewer) httpSession.getAttribute(SessionAttributes.MENU_VIEWER);
			if (menuViewer == null) {
				menuViewer = new GalleryMenuViewer();
				httpSession.setAttribute(SessionAttributes.MENU_VIEWER, menuViewer);
			}
		}
		
		// Set initially selected sample, if any
		boolean isSampleSelected = false;
		String selectionID = null;
		if(SampleGalleryAction.hasInitialSelection()) {
			selectionID = SampleGalleryAction.getInitialSelectionID();
			SampleGalleryAction.clearInitialSelectionID();
		} else {
			selectionID = req.getParameter(RequestArguments.GALLERY_SELECTED_SAMPLE);
		}
		if(selectionID == null) {
			String selectionURL = req.getParameter(RequestArguments.GALLERY_SELECTED_SAMPLE_URL);
			if(selectionURL != null) {
				int sgIndex = selectionURL.indexOf("/SampleGallery"); //$NON-NLS-1$
				if(sgIndex > 0) {
					selectionURL = selectionURL.substring(sgIndex ,selectionURL.length() -1);
					selectionID = menuViewer.getGalleryForest().getIdForURL(selectionURL);
				}
			}
		}
		if(selectionID != null) {
			if(!selectionID.equals("")) { //$NON-NLS-1$
				GalleryTreeNode sampleNode = menuViewer.getGalleryForest().getNode(selectionID);
				if(sampleNode != null) {
					menuViewer.setSelectedSample(selectionID);
					isSampleSelected = true;
				}
			}
		}
		if(!isSampleSelected) {
			menuViewer.setSelectedSample(""); //$NON-NLS-1$
		}
		
		resp.setContentType("text/html;charset=UTF-8"); //$NON-NLS-1$
		String htmlMenu = menuViewer.getAsHTML(localeName);
		resp.getWriter().println(htmlMenu);
	}
}
