/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation.
 * All rights reserved. 
 *******************************************************************************/

package com.ibm.tutorialsgallery.servlets;

import java.io.IOException;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.*;
import org.eclipse.core.runtime.*;
import org.eclipse.help.ILiveHelpAction;
import org.osgi.framework.Bundle;

import com.ibm.tutorialgallery.internal.*;

/**
 * Servlet to handle live help action requests
 */
public class GalleryServlet extends HttpServlet implements GalleryConstants {
	
	/**
	 */
	public void init() throws ServletException {
		// Nothing
	}

	private void handleError(HttpServletRequest req, HttpServletResponse resp, String errorStringKey) {
		this.handleError(req, resp, errorStringKey, null, null);
	}

	private void handleError(HttpServletRequest req, HttpServletResponse resp, String errorStringKey, String info, Exception exception) {
		if(null != exception) {
			req.setAttribute(RequestArguments.GALLERY_EXCEPTION, exception);
		}
		if(null != info) {
			req.setAttribute(RequestArguments.GALLERY_ERROR_INFO_OBJECT, info);
		}
		req.setAttribute(RequestArguments.GALLERY_ERROR, errorStringKey);
		RequestDispatcher dispatcher = getServletContext().getRequestDispatcher(GALLERY_ERROR_URL);
		try {
			dispatcher.forward(req, resp);
		} catch (ServletException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Called by the server (via the <code>service</code> method) to
	 * allow a servlet to handle a GET request. 
	 */
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
		throws ServletException, IOException {
		
		req.setCharacterEncoding("UTF-8"); //$NON-NLS-1$
		String pluginID = req.getParameter("pluginID"); //$NON-NLS-1$
		if (pluginID == null) {
			this.handleError(req, resp, I18N.ERROR_GALLERY_MISSING_PARAMETER_PLUGINID);
			return;
		}
		String className = req.getParameter("class"); //$NON-NLS-1$
		if (className == null) {
			this.handleError(req, resp, I18N.ERROR_GALLERY_MISSING_PARAMETER_CLASS);
			return;
		}
		String arg = req.getParameter("arg"); //$NON-NLS-1$
		Bundle plugin = Platform.getBundle(pluginID);
		if (plugin == null) {
			this.handleError(req, resp, I18N.ERROR_GALLERY_PLUGIN_NOT_FOUND, pluginID, null);
			return;
		}
				
		Class c;
		try {
			c = plugin.loadClass(className);
		} catch (ClassNotFoundException e) {
			this.handleError(req, resp, I18N.ERROR_GALLERY_CLASS_LOAD_FAILURE, className, e);
			return;
		}
		try{
			Object o = c.newInstance();
			if (o instanceof ILiveHelpAction) {
				ILiveHelpAction helpExt = (ILiveHelpAction) o;
				if (arg != null) {

					helpExt.setInitializationString(arg);
				}
				Thread runnableLiveHelp = new Thread(helpExt);
				resp.setStatus(HttpServletResponse.SC_NO_CONTENT);
				resp.flushBuffer();
				runnableLiveHelp.setDaemon(true);
				runnableLiveHelp.start();
			}
		} catch (ThreadDeath td) {
			throw td;
		} catch (Exception e) {
			this.handleError(req, resp, I18N.ERROR_GALLERY_SERVLET_UNKNOWN_ERROR, null, e);
		}
	}
	/**
	 *
	 * Called by the server (via the <code>service</code> method)
	 * to allow a servlet to handle a POST request.
	 *
	 * Handle the search requests,
	 *
	 */
	protected void doPost(HttpServletRequest req, HttpServletResponse resp)
		throws ServletException, IOException {
		doGet(req, resp);
	}
}
